@@ -22,6 +22,10 @@ class Kosten(Geschaeftsobjekt):
     """
     Dieses BO wird zur Übertagung von hierarchischen Kostenstrukturen verwendet.
     Die Kosten werden dabei in Kostenblöcke und diese wiederum in Kostenpositionen strukturiert.
+
+    .. HINT::
+        `Kosten JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/KostenSchema.json>`_"
+
     """
 
     # required attributes
