@@ -81,6 +81,10 @@ class Lastgang(Geschaeftsobjekt, _LastgangBody):
     Modell zur Abbildung eines Lastganges;
     In diesem Modell werden die Messwerte mit einem vollständigen Zeitintervall angegeben und es bietet daher eine hohe
     Flexibilität in der Übertragung jeglicher zeitlich veränderlicher Messgrössen.
+
+    .. HINT::
+        `Lastgang JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/LastgangSchema.json>`_"
+
     """
 
     # required attributes
