@@ -29,6 +29,9 @@ from bo4e.validators import validate_marktlokations_id
 class Marktlokation(Geschaeftsobjekt):
     """
     Object containing information about a Marktlokation
+
+    .. HINT::
+        `Marktlokation JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/MarktlokationSchema.json>`_
     """
 
     # required attributes
