@@ -36,6 +36,9 @@ _melo_id_pattern = re.compile(r"^[A-Z]{2}\d{6}\d{5}[A-Z\d]{20}$")
 class Messlokation(Geschaeftsobjekt):
     """
     Object containing information about a Messlokation
+
+    .. HINT::
+        `Messlokation JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/MesslokationSchema.json>`_
     """
 
     # pylint: disable=unused-argument, no-self-use
