@@ -15,6 +15,9 @@ from bo4e.enum.botyp import BoTyp
 class Tarifkosten(Tarifinfo):
     """
     Objekt zur Kommunikation von Kosten, die im Rahmen der Tarifanwendung entstehen
+
+    .. HINT::
+        `Tarifkosten JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/TarifkostenSchema.json>`_
     """
 
     # required attributes
