@@ -31,6 +31,9 @@ def strasse_xor_postfach(instance, attribute, value):
 class Adresse(COM):
     """
     Contains an address that can be used for most purposes.
+
+    .. HINT::
+        `Adresse JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/AdresseSchema.json>`_
     """
 
     # required attributes
