@@ -21,6 +21,9 @@ from bo4e.validators import check_list_length_at_least_one
 class Angebotsvariante(COM):
     """
     Führt die verschiedenen Ausprägungen der Angebotsberechnung auf
+
+    .. HINT::
+        `Angebotsvariante JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/AngebotsvarianteSchema.json>`_
     """
 
     # required attributes
