@@ -24,6 +24,9 @@ class AufAbschlag(COM):
     """
     Modell für die preiserhöhenden (Aufschlag) bzw. preisvermindernden (Abschlag) Zusatzvereinbarungen,
     die individuell zu einem neuen oder bestehenden Liefervertrag abgeschlossen wurden.
+
+    .. HINT::
+        `AufAbschlag JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/AufAbschlagSchema.json>`_
     """
 
     # required attributes
