@@ -16,6 +16,9 @@ from bo4e.com.com import COM, COMSchema
 class AufAbschlagstaffelProOrt(COM):
     """
     Gibt den Wert eines Auf- oder Abschlags und dessen Staffelgrenzen an
+
+    .. HINT::
+        `AufAbschlagstaffelProOrt JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/AufAbschlagstaffelProOrtSchema.json>`_
     """
 
     # required attributes
