@@ -16,6 +16,9 @@ from bo4e.enum.dienstleistungstyp import Dienstleistungstyp
 class Dienstleistung(COM):
     """
     Abbildung einer abrechenbaren Dienstleistung.
+
+    .. HINT::
+        `Dienstleistung JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/DienstleistungSchema.json>`_
     """
 
     # required attributes
