@@ -23,6 +23,10 @@ from bo4e.validators import check_list_length_at_least_one
 class Energiemix(COM):
     """
     Zusammensetzung der gelieferten Energie aus den verschiedenen Primärenergieformen.
+
+    .. HINT::
+        `Energiemix JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/EnergiemixSchema.json>`_
+
     """
 
     # required attributes
