@@ -15,6 +15,9 @@ from bo4e.com.com import COM, COMSchema
 class Geokoordinaten(COM):
     """
     This component provides the geo-coordinates for a location.
+
+    .. HINT::
+        `Geokoordinaten JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/GeokoordinatenSchema.json>`_
     """
 
     # = attr.ib() has to be there, to make the validator work
