@@ -17,6 +17,9 @@ from bo4e.com.geraeteeigenschaften import Geraeteeigenschaften, Geraeteeigenscha
 class Geraet(COM):
     """
     Mit dieser Komponente werden alle Geräte modelliert, die keine Zähler sind.
+
+    .. HINT::
+        `Geraet JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/GeraetSchema.json>`_
     """
 
     # optional attributes
