@@ -16,6 +16,9 @@ from bo4e.enum.geraetetyp import Geraetetyp
 class Hardware(COM):
     """
     Abbildung einer abrechenbaren Hardware.
+
+    .. HINT::
+        `Hardware JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/HardwareSchema.json>`_
     """
 
     # required attributes
