@@ -19,6 +19,9 @@ from bo4e.validators import check_bis_is_later_than_von
 class Kostenposition(COM):
     """
     Diese Komponente wird zur Übertagung der Details zu einer Kostenposition verwendet.
+
+    .. HINT::
+        `Kostenposition JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/KostenpositionSchema.json>`_
     """
 
     # required attributes
