@@ -17,6 +17,9 @@ from bo4e.enum.tarifregionskriterium import Tarifregionskriterium
 class KriteriumWert(COM):
     """
     Mit dieser Komponente können Kriterien und deren Werte definiert werden
+
+    .. HINT::
+        `KriteriumWert JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/KriteriumWertSchema.json>`_
     """
 
     # required attributes
