@@ -13,6 +13,9 @@ from bo4e.com.com import COM, COMSchema
 class MarktgebietInfo(COM):
     """
     Informationen zum Marktgebiet im Gas.
+
+    .. HINT::
+        `MarktgebietInfo JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/MarktgebietInfoSchema.json>`_
     """
 
     # required attributes
