@@ -18,6 +18,9 @@ from bo4e.enum.mengeneinheit import Mengeneinheit
 class Menge(COM):
     """
     Abbildung einer Menge mit Wert und Einheit.
+
+    .. HINT::
+        `Menge JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/MengeSchema.json>`_
     """
 
     # required attributes
