@@ -19,6 +19,10 @@ class Messlokationszuordnung(COM):
     Mit dieser Komponente werden Messlokationen zu Marktlokationen zugeordnet.
     Dabei kann eine arithmetische Operation (Addition, Subtraktion, Multiplikation, Division) angegeben werden,
     mit der die Messlokation zum Verbrauch der Marktlokation beiträgt.
+
+    .. HINT::
+        `Messlokationszuordnung JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/MesslokationszuordnungSchema.json>`_
+
     """
 
     # required attributes
