@@ -27,6 +27,9 @@ from bo4e.validators import check_list_length_at_least_one
 class Preisposition(COM):
     """
     Preis für eine definierte Lieferung oder Leistung innerhalb eines Preisblattes
+
+    .. HINT::
+        `Preisposition JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/PreispositionSchema.json>`_
     """
 
     # required attributes
