@@ -19,6 +19,9 @@ from bo4e.enum.gueltigkeitstyp import Gueltigkeitstyp
 class RegionaleGueltigkeit(COM):
     """
     Mit dieser Komponente können regionale Gültigkeiten, z.B. für Tarife, Zu- und Abschläge und Preise definiert werden.
+
+    .. HINT::
+        `RegionaleGueltigkeit JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/RegionaleGueltigkeitSchema.json>`_
     """
 
     # required attributes
