@@ -15,6 +15,9 @@ from bo4e.com.regionalegueltigkeit import RegionaleGueltigkeit, RegionaleGueltig
 class RegionalePreisgarantie(Preisgarantie):
     """
     Abbildung einer Preisgarantie mit regionaler Abgrenzung
+
+    .. HINT::
+        `RegionalePreisgarantie JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/RegionalePreisgarantieSchema.json>`_
     """
 
     # required attributes
