@@ -14,6 +14,9 @@ from bo4e.com.regionalegueltigkeit import RegionaleGueltigkeit, RegionaleGueltig
 class RegionalePreisstaffel(Preisstaffel):
     """
     Abbildung einer Preisstaffel mit regionaler Abgrenzung
+
+    .. HINT::
+        `RegionalePreisstaffel JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/RegionalePreisstaffelSchema.json>`_
     """
 
     # required attributes
