@@ -17,6 +17,9 @@ from bo4e.enum.regionskriteriumtyp import Regionskriteriumtyp
 class Regionskriterium(COM):
     """
     Komponente zur Abbildung eines Regionskriteriums
+
+    .. HINT::
+        `Regionskriterium JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/RegionskriteriumSchema.json>`_
     """
 
     # required attributes
