@@ -15,6 +15,9 @@ from bo4e.com.com import COM, COMSchema
 class StandorteigenschaftenAllgemein(COM):
     """
     Allgemeine Standorteigenschaften
+
+    .. HINT::
+        `StandorteigenschaftenAllgemein JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/StandorteigenschaftenAllgemeinSchema.json>`_
     """
 
     # required attributes
