@@ -14,6 +14,9 @@ from bo4e.com.com import COM, COMSchema
 class StandorteigenschaftenStrom(COM):
     """
     Standorteigenschaften der Sparte Strom
+
+    .. HINT::
+        `StandorteigenschaftenStrom JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/StandorteigenschaftenStromSchema.json>`_
     """
 
     # required attributes
