@@ -19,6 +19,9 @@ from bo4e.enum.waehrungscode import Waehrungscode
 class Steuerbetrag(COM):
     """
     Abbildung eines Steuerbetrages.
+
+    .. HINT::
+        `Steuerbetrag JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/SteuerbetragSchema.json>`_
     """
 
     # required attributes
