@@ -18,6 +18,9 @@ from bo4e.enum.preistyp import Preistyp
 class Tarifpreis(Preis):
     """
     Abbildung eines Tarifpreises mit Preistyp und Beschreibung abgeleitet von COM Preis.
+
+    .. HINT::
+        `Tarifpreis JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/TarifpreisSchema.json>`_
     """
 
     # required attributes
