@@ -19,6 +19,9 @@ from bo4e.enum.mengeneinheit import Mengeneinheit
 class Zaehlwerk(COM):
     """
     Mit dieser Komponente werden Zählwerke modelliert.
+
+    .. HINT::
+        `Zaehlwerk JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/ZaehlwerkSchema.json>`_
     """
 
     zaehlwerk_id: str = attr.ib(
