@@ -16,6 +16,9 @@ class Zeitintervall(COM):
     """
     Abbildung für ein Zeitintervall. Die Abbildung eines Zeitintervalls.
     Z.B. zur Anwendung als Raster in äquidistanten Zeitreihen/Lastgängen, beispielsweise 15 Minuten.
+
+    .. HINT::
+        `Zeitintervall JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/ZeitintervallSchema.json>`_
     """
 
     # required attributes
